==> pdal-2.5.2.tgz: include/pdal/compression/LzmaCompression.hpp <==
/******************************************************************************
* Copyright (c) 2014, Howard Butler (howard@hobu.co)
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following
* conditions are met:
*
*     * Redistributions of source code must retain the above copyright
*       notice, this list of conditions and the following disclaimer.
*     * Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in
*       the documentation and/or other materials provided
*       with the distribution.
*     * Neither the name of Hobu, Inc. or Flaxen Geo Consulting nor the
*       names of its contributors may be used to endorse or promote
*       products derived from this software without specific prior
*       written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
* COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
* OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
* AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
* OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
* OF SUCH DAMAGE.
****************************************************************************/
#pragma once

#include "Compression.hpp"

namespace pdal
{

class LzmaCompressorImpl;
class LzmaCompressor : public Compressor
{
public:
    PDAL_DLL LzmaCompressor(BlockCb cb);
    PDAL_DLL ~LzmaCompressor();

    PDAL_DLL void compress(const char *buf, size_t bufsize);
    PDAL_DLL void done();

private:
    std::unique_ptr<LzmaCompressorImpl> m_impl;
};


class LzmaDecompressorImpl;

class LzmaDecompressor : public Decompressor
{
public:
    PDAL_DLL LzmaDecompressor(BlockCb cb);
    PDAL_DLL ~LzmaDecompressor();

    PDAL_DLL void decompress(const char *buf, size_t bufsize);
    PDAL_DLL void done();

private:
    std::unique_ptr<LzmaDecompressorImpl> m_impl;
};

} // namespace pdal

==> pdal-2.9.0.tgz: include/pdal/compression/LzmaCompression.hpp <==
/******************************************************************************
* Copyright (c) 2014, Howard Butler (howard@hobu.co)
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following
* conditions are met:
*
*     * Redistributions of source code must retain the above copyright
*       notice, this list of conditions and the following disclaimer.
*     * Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in
*       the documentation and/or other materials provided
*       with the distribution.
*     * Neither the name of Hobu, Inc. or Flaxen Geo Consulting nor the
*       names of its contributors may be used to endorse or promote
*       products derived from this software without specific prior
*       written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
* COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
* OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
* AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
* OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
* OF SUCH DAMAGE.
****************************************************************************/
#pragma once

#include "Compression.hpp"

namespace pdal
{

class LzmaCompressorImpl;
class LzmaCompressor : public Compressor
{
public:
    PDAL_EXPORT LzmaCompressor(BlockCb cb);
    PDAL_EXPORT ~LzmaCompressor();

    PDAL_EXPORT void compress(const char *buf, size_t bufsize);
    PDAL_EXPORT void done();

private:
    std::unique_ptr<LzmaCompressorImpl> m_impl;
};


class LzmaDecompressorImpl;

class LzmaDecompressor : public Decompressor
{
public:
    PDAL_EXPORT LzmaDecompressor(BlockCb cb);
    PDAL_EXPORT ~LzmaDecompressor();

    PDAL_EXPORT void decompress(const char *buf, size_t bufsize);
    PDAL_EXPORT void done();

private:
    std::unique_ptr<LzmaDecompressorImpl> m_impl;
};

} // namespace pdal
